require 'rubygems'
require 'fastercsv'
require 'dm-core'
require 'dm-migrations'

module CSVToSqlite
  
  class Parser
    
    attr_reader :db
    attr_reader :klass
    attr_reader :column_names
    
    def initialize(source, target, table_name=nil, column_names=nil)
      if File.exists?(source)
        @source = IO.readlines(source).to_s
      else
        @source = source
      end
      
      @target = target
      @table_name = table_name || 'item'
      @column_names = column_names || _name_columns(@source)
      
      _connect(@target)
      _create_model(@table_name, @column_names)
      
      DataMapper.finalize
      DataMapper.auto_migrate!
    end
    
    def parse!
      _parse(@source)
    end
    
    private
    
      def _connect(target)
        @db = DataMapper.setup(:default, "sqlite:///#{File.expand_path(target)}")
      end
    
      def _create_model(table_name, column_names)
        @klass = DataMapper::Model.new do
          property :id, DataMapper::Property::Serial
          column_names.each do |column|
            property column.to_s.to_sym, DataMapper::Property::String
          end
        end
      end
      
      def _name_columns(source)
        columns = []
        columns_count = 0
        FasterCSV.parse(source) do |row|
          columns_count = row.length if row.length > columns_count
        end
        (0...columns_count).each {|i| columns.push("col_#{i.to_s}")}
        columns
      end
      
      def _parse(source)
        FasterCSV.parse(source) do |row|
          item = @klass.new()
          row.each_with_index do |column, index|
            item.send("#{@column_names[index]}=", column)
          end
          item.save
        end
      end
    
  end
  
end