require 'optparse'

module CSVToSqlite

  class Runner

    attr_reader :argv
    attr_reader :parser
    attr_reader :options
    attr_reader :command
    attr_reader :arguments

    def initialize(argv)
      @argv = argv
      @options = {
        :verbose =>     true
      }
      init_parser
    end

    def run
      parse!
      CSVToSqlite::Parser.new(@source, @target, @options[:table], @options[:columns]).parse!
    end
    
    protected

    def init_parser
      
      @parser ||= OptionParser.new do |opts|
        opts.banner = "Usage: csv_to_sqlite [OPTIONS] source target"
        opts.separator ""
        opts.on('-t', '--table TABLE_NAME', 'The name of the table to create in the database.')                   { |table| @options[:table] = table }
        opts.on('-c', '--columns COLUMN_NAMES', 'Comma separated list of column names. Ex: one,two,three...')     { |columns| @options[:columns] = columns.split(',') }
        opts.on('-q', '--quiet')                                                                                  { |quiet| @options[:verbose] = false }
        opts.on('-v', '--version')                                                                                { puts version ; exit }
        opts.on('-h', '--help')                                                                                   { puts opts ; exit }
        opts.on("-D", "--debug", "Set debugging on")                                                              { @options[:debug] = true }
        opts.separator ""
      end
      
    end
    
    def parse!
      
      begin
        @parser.parse!(@argv)
      rescue
        puts @parser.help
        exit 1
      end
      
      @source = @argv.shift
      
      if @source.nil?
        puts @parser.help
        exit 1
      end
      
      @target = @argv.shift
      
      if @target.nil?
        puts @parser.help
        exit 1
      end
      
      @arguments = @argv
    
    end

    def version
      "csv_to_sqlite #{GPC::VERSION}"
    end

  end

end